"""
Installation

# easy_install django-admin-skel

Using

1. Your admin templates must extends admin_skel/index.html

{% extends "admin_skel/index.html" %}

2. You must define blocks "header", "content", "footer", "title" in your templates

3. You can define block "scripts" to load add scripts into <header> tag

4. You must provide menu into template in such format:
   menu = [
        {
            'title': _(u'Top menu 1'),
            'url': reverse('some url'),
        },
        {
            'title': _(u'Top menu 2'),
            'url': reverse('some another url'),
        },
        {
            'title': _(u'Top menu 3 with subitems'),
            'submenu': [
              {
               'title': _(u'Submenu 1'),
               'url': reverse('submenu url'),
               ...
            
            ]
        },


   
   ]

This may be done by context-processor

#settings.py

TEMPLATE_CONTEXT_PROCESSORS = (
   ...
 	'main.context_processors.menu',
   ...
)


#main.context_processors

def menu(request):
    
    menu = [
        {
            'title': _(u'Devices'),
            'url': reverse('admin:devices'),
        },
        {
            'title': _(u'Developers'),
            'url': reverse('admin:developers'),
        },
        {
            'title': _(u'Users'),
            'url': reverse('admin:users'),
        }
    ]

    selected = None
    opened = None
    if request.path != '/':
        # select and open direct match
        for item in menu:
            if 'submenu' in item:
                for subitem in item['submenu']:
                    if subitem['url'] == request.path:
                        subitem['selected'] = True
                        item['opened'] = True
                        selected = subitem
                        opened = item
                        break
            else:
                if item['url'] == request.path:
                    item['selected'] = True
                    selected = item
                    break

        # open almost-the-same items
        if not opened:
            for item in menu:
                if 'submenu' in item:
                    for subitem in item['submenu']:
                        if request.path.startswith(subitem['url']):
                            item['opened'] = True
                            break
    
    return {'menu': menu}


5. You may override menu rendered with your own by defining block "menu"

"""




from os.path import realpath, dirname, join
import warnings

from django.core.management.commands.runserver import Command as _Command


class Command(_Command):
    def __init__(self, *args, **kwargs):
        _Command.__init__(self, *args, **kwargs)
        warnings.warn('You are using modified runserver from django-admin-skel.', Warning)
        for opt in self.option_list:
            if opt.dest == 'admin_media_path':
                opt.default = join(dirname(dirname(dirname(realpath(__file__)))), 'media')






#!/usr/bin/env python

from setuptools import setup, find_packages
setup(name='django-admin-skel',
      version='1.0.0p3',
      description='Basic admin styles for django (non django.contrib.admin). Maintained by Alexey Loshkarev <alexey@smscoin.com>',
      author='Andrey Shuster',
      author_email='andrey@smscoin.com',
      url='http://pypi.python.org/pypi/django-admin-skel/',
      packages=find_packages(),
      license='GPL',
      classifiers=[
          "Development Status :: 5 - Production/Stable", 
          "Intended Audience :: Developers",
          "License :: OSI Approved :: GNU General Public License (GPL)",
          "Natural Language :: English",
          "Programming Language :: Python",
          "Topic :: Software Development :: Libraries :: Python Modules",
          ],
      zip_safe=False,
      include_package_data=True,
      )
